@@ -9,14 +9,12 @@
 #'
 #' @export
 #' @inheritParams use_template
-use_cran_comments <- function(open = interactive()) {
+use_cran_comments <- function(open = rlang::is_interactive()) {
   check_is_package("use_cran_comments()")
   use_template(
     "cran-comments.md",
-    data = list(rversion = paste0(version$major, ".", version$minor)),
+    data = list(rversion = glue("{version$major}.{version$minor}")),
     ignore = TRUE,
     open = open
   )
-
-  invisible(TRUE)
 }
