@@ -1,21 +1,29 @@
-#' Create a release issue checklist
+#' Create a release checklist in a GitHub issue
 #'
-#' When preparing to release a package there are quite a few steps that
-#' need to be performed, and some of the steps can take multiple hours.
-#' This function creates an issue checklist so that you can keep track of
-#' where you are in the process, and feel a sense of satisfaction as you
-#' progress. It also helps watchers of your package stay informed about where
-#' you are in the process.
+#' When preparing to release a package there are quite a few steps that need to
+#' be performed, and some of the steps can take multiple hours. This function
+#' creates an issue checklist so that you can keep track of where you are in the
+#' process, and feel a sense of satisfaction as you progress. It also helps
+#' watchers of your package stay informed about where you are in the process.
 #'
-#' @param version Version number for release
+#' @param version Optional version number for release. If unspecified, you can
+#'   make an interactive choice.
 #' @export
 #' @examples
 #' \dontrun{
 #' use_release_issue("2.0.0")
 #' }
 use_release_issue <- function(version = NULL) {
-  check_uses_github()
   check_is_package("use_release_issue()")
+  tr <- target_repo(github_get = TRUE)
+  if (!isTRUE(tr$can_push)) {
+    ui_line("
+      It is very unusual to open a release issue on a repo you can't push to:
+        {ui_value(tr$repo_spec)}")
+    if (ui_nope("Do you really want to do this?")) {
+      ui_stop("Aborting.")
+    }
+  }
 
   version <- version %||% choose_version()
   if (is.null(version)) {
@@ -25,11 +33,11 @@ use_release_issue <- function(version = NULL) {
   on_cran <- !is.null(cran_version())
   checklist <- release_checklist(version, on_cran)
 
-  issue <- gh::gh("POST /repos/:owner/:repo/issues",
-    owner = github_owner(),
-    repo = github_repo(),
+  gh <- gh_tr(tr)
+  issue <- gh(
+    "POST /repos/{owner}/{repo}/issues",
     title = glue("Release {project_name()} {version}"),
-    body = paste(checklist, "\n", collapse = "")
+    body = paste0(checklist, "\n", collapse = "")
   )
 
   view_url(issue$html_url)
@@ -40,7 +48,7 @@ release_checklist <- function(version, on_cran) {
   cran_results <- cran_results_url()
   has_src <- dir_exists(proj_path("src"))
   has_news <- file_exists(proj_path("NEWS.md"))
-  has_pkgdown <- file_exists(proj_path("_pkgdown.yml"))
+  has_pkgdown <- uses_pkgdown()
   has_readme <- file_exists(proj_path("README.Rmd"))
   has_extra <- exists("release_bullets", parent.env(globalenv()))
 
@@ -64,9 +72,10 @@ release_checklist <- function(version, on_cran) {
     todo("`rhub::check(platform = 'ubuntu-rchk')`", has_src),
     todo("`rhub::check_with_sanitizers()`", has_src),
     todo("`revdepcheck::revdep_check(num_workers = 4)`", on_cran),
+    todo("`urlchecker::url_check()`"),
     todo("Update `cran-comments.md`"),
     todo("[Polish NEWS](https://style.tidyverse.org/news.html#news-release)", on_cran),
-    todo("Review pkgdown reference index for, e.g., missing topics", has_pkgdown),
+    todo("Review pkgdown reference index for, e.g., missing topics", has_pkgdown && type != "patch"),
     todo("Draft blog post", type != "patch"),
     if (has_extra) paste0("* [ ] ", get("release_bullets", parent.env(globalenv()))()),
     "",
@@ -105,41 +114,53 @@ release_type <- function(version) {
 #'
 #' Creates a __draft__ GitHub release for the current package using the current
 #' version and `NEWS.md`. If you are comfortable that it is correct, you will
-#' need to publish the release from GitHub. It also deletes `CRAN-RELEASE`
-#' and checks that you've pushed all commits to GitHub.
+#' need to publish the release from GitHub. It also deletes `CRAN-RELEASE` and
+#' checks that you've pushed all commits to GitHub.
 #'
-#' @inheritParams use_github_links
+#' @param host,auth_token \lifecycle{defunct}: No longer consulted now that
+#'   usethis allows the gh package to lookup a token based on a URL determined
+#'   from the current project's GitHub remotes.
 #' @export
-use_github_release <- function(host = NULL,
-                               auth_token = github_token()) {
-  cran_release <- proj_path("CRAN-RELEASE")
-  if (file_exists(cran_release)) {
-    file_delete(cran_release)
+use_github_release <- function(host = deprecated(),
+                               auth_token = deprecated()) {
+  if (lifecycle::is_present(host)) {
+    deprecate_warn_host("use_github_release")
+  }
+  if (lifecycle::is_present(auth_token)) {
+    deprecate_warn_auth_token("use_github_release")
   }
 
-  check_uses_github()
+  tr <- target_repo(github_get = TRUE)
+  if (!isTRUE(tr$can_push)) {
+    ui_stop("
+      You don't seem to have push access for {ui_value(tr$repo_spec)}, which \\
+      is required to draft a release.")
+  }
+
+  challenge_non_default_branch(
+    "Are you sure you want to create a release on a non-default branch?"
+  )
   check_branch_pushed()
-  check_github_token(auth_token)
 
   path <- proj_path("NEWS.md")
   if (!file_exists(path)) {
     ui_stop("{ui_path('NEWS.md')} not found")
   }
-  news <- news_latest(read_utf8(path))
 
+  cran_release <- proj_path("CRAN-RELEASE")
+  if (file_exists(cran_release)) {
+    file_delete(cran_release)
+  }
+  news <- news_latest(read_utf8(path))
   package <- package_data()
 
-  release <- gh::gh(
-    "POST /repos/:owner/:repo/releases",
-    owner = github_owner(),
-    repo = github_repo(),
+  gh <- gh_tr(tr)
+  release <- gh(
+    "POST /repos/{owner}/{repo}/releases",
     tag_name = paste0("v", package$Version),
-    target_commitish = git_commit_find()$sha,
+    target_commitish = gert::git_info(repo = git_repo())$commit,
     name = paste0(package$Package, " ", package$Version),
-    body = news,
-    draft = TRUE,
-    .api_url = host,
-    .token = auth_token
+    body = news, draft = TRUE
   )
 
   view_url(release$html_url)
