@@ -14,11 +14,13 @@
 #'   spelling errors are found. Defaults to `FALSE`, which does not error, but
 #'   prints potential spelling errors
 #' @export
-use_spell_check <- function(vignettes = TRUE, lang = "en-US", error = FALSE) {
+use_spell_check <- function(vignettes = TRUE,
+                            lang = "en-US",
+                            error = FALSE) {
   check_is_package("use_spell_check")
   check_installed("spelling")
   use_dependency("spelling", "Suggests")
-  use_description_field("Language", lang)
+  use_description_field("Language", lang, overwrite = TRUE)
   spelling::spell_check_setup(
     pkg = proj_get(), vignettes = vignettes, lang = lang, error = error
   )
